package VMOMI::HostConfigChangeMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
